@@ -5,6 +5,7 @@ import sys
 import getpass
 import invoke
 import crypt
+import platform
 
 try:
     import yaml
@@ -26,8 +27,8 @@ class Configuration:
             self.username = username
             self.password = password
             self.shell = user_shell if (user_shell is not None and not user_shell.isspace() and len(user_shell) > 0) else '"/usr/bin/bash"' 
-            self.is_system_user = True if (system_user is not None and not system_user.isspace() and len(system_user) > 0 and system_user.lower() != 'false') else False
-            self.groups = user_groups if (user_groups is not None and not user_groups.isspace() and len(user_groups) > 0) else []
+            self.is_system_user = system_user
+            self.groups = [group for group in user_groups if not group.isspace()] if user_groups is not None else []
             self.home_directory = home_directory if (home_directory is not None and not home_directory.isspace() and len(home_directory) > 0) else None
             self.install_shell_if_missing = install_shell_if_missing
             if isinstance(self.groups, str):
@@ -38,16 +39,22 @@ class Configuration:
             if self.ssh_key:
                 if 'default' == self.ssh_key.lower():
                     current_user = getuser()
-                    # TODO Make this OS agnostic
-                    ssh_key = f'/home/{current_user}/.ssh/id_rsa.pub'
+                    if platform.system() == 'Windows':
+                        ssh_key = os.path.join('C:\\', 'Users', current_user, '.ssh', 'id_rsa.pub')
+                    else:
+                        ssh_key = os.path.join('/home', current_user, '.ssh', 'id_rsa.pub')
                     if os.path.exists(ssh_key):
                         self.ssh_key = ssh_key
                     else:
                         print(f'Unable to default ssh key for user: {current_user}')
                         self.ssh_key = None
-                elif "/" not in self.ssh_key:
+                elif "/" not in self.ssh_key and "\\" not in self.ssh_key:
                     current_user = getuser()
-                    ssh_key = f'/home/{current_user}/.ssh/{self.ssh_key}.pub'
+                    if platform.system() == 'Windows':
+                        ssh_key = os.path.join('C:\\', 'Users', current_user, '.ssh', f'{self.ssh_key}.pub')
+                    else:
+                        ssh_key = os.path.join('/home', current_user, '.ssh', f'{self.ssh_key}.pub')
+
                     if os.path.exists(ssh_key):
                         self.ssh_key = ssh_key
                     else:
@@ -142,7 +149,7 @@ class Configuration:
             self.user_add_command += f'--shell={Configuration.UserConfig.__SHELL_PLACEHOLDER} '
             self.user_add_command += Configuration.UserConfig.__GROUPS_PLACEHOLDER
             if self._user.password:
-                self.user_add_command += '--password ' + crypt(self._user.password).replace("$",r"$") + ' '
+                self.user_add_command += "--password '" + crypt(self._user.password).replace("$",r"$") + "' "
             self.user_add_command += self._user.username
 
     class ConnectionConfig(Config):
@@ -184,8 +191,10 @@ class Configuration:
         def __parse_ssh_key(self, ssh_key):
             if ssh_key is None:
                 current_user = getuser()
-                # TODO make this os independent
-                check_ssh_key = f'/home/{current_user}/.ssh/id_rsa'
+                if platform.system() == 'Windows':
+                    ssh_key = os.path.join('C:\\', 'Users', current_user, '.ssh', 'id_rsa')
+                else:
+                    check_ssh_key = os.path.join('/home', current_user, '.ssh', 'id_rsa')
                 if os.path.exists(check_ssh_key):
                     ssh_key = check_ssh_key
                     if Configuration.VERBOSE:
@@ -423,7 +432,7 @@ class Configuration:
             sys.exit(1)
 
         connection_setup = None
-        extension = input_file.split('.')[1]
+        extension = input_file.split('.')[-1]
         if extension in JSON:
             with open(input_file) as json_data:
                 connection_setup = json.load(json_data)
@@ -431,6 +440,9 @@ class Configuration:
             with open(input_file) as yaml_data:
                 connection_setup = yaml.safe_load(yaml_data)
 
+        if not connection_setup:
+            raise Exception(f'Unable to load configuration file {input_file}')
+
         if 'server_connection' in connection_setup.keys():
             self.connection_config = Configuration.ConnectionConfig(connection_setup['server_connection'])
         else:
@@ -464,6 +476,13 @@ class Configuration:
             shell = u['shell'] if 'shell' in u.keys() else None
             groups = u['groups'] if 'groups' in u.keys() else None
             system_user = u['system_user'] if 'system_user' in u.keys() else None
+
+            try:
+                if system_user.lower() == 'false':
+                    system_user = False
+            except Exception:
+                pass
+
             ssh_key = u['ssh_key'] if 'ssh_key' in u.keys() and not system_user else None
             home_directory = u['home_directory'] if 'home_directory' in u.keys() and not system_user else None
             install_shell_if_missing = True if not system_user else False
